
import sys
import re

include = sys.argv[1]
msg_basename = sys.argv[2]
count = 1

m = re.search(r'(.*\D)(\d+)$', sys.argv[2])
if m:
  msg_basename = m.group(1)
  count = int(m.group(2))

print('''
#include "{include}"

char buf[1];

int main() {{
'''.format(include=include))

def RefMessage(name):
  print('''
  {{
    {name} proto;
    proto.ParseFromArray(buf, 0);
    proto.SerializePartialToArray(&buf[0], 0);
  }}
  '''.format(name=name))

RefMessage(msg_basename)

for i in range(2, count + 1):
  RefMessage(msg_basename + str(i))

print('''
  return 0;
}''')



# Copyright 2018 gRPC authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


cdef extern from "pthread.h" nogil:
    int pthread_atfork(
        void (*prepare)() nogil,
        void (*parent)() nogil,
        void (*child)() nogil)


cdef void __prefork() nogil


cdef void __postfork_parent() nogil


cdef void __postfork_child() nogil